import { eventTarget, utilities } from '@cornerstonejs/core';
import SplineROITool from './SplineROITool';
import { Events } from '../../enums';
import { convertContourSegmentationAnnotation } from '../../utilities/contourSegmentation';
class SplineContourSegmentationTool extends SplineROITool {
    static { this.toolName = 'SplineContourSegmentationTool'; }
    constructor(toolProps) {
        const initialProps = utilities.deepMerge({
            configuration: {
                calculateStats: false,
            },
        }, toolProps);
        super(initialProps);
        this.annotationCutMergeCompletedBinded =
            this.annotationCutMergeCompleted.bind(this);
    }
    isContourSegmentationTool() {
        return true;
    }
    initializeListeners() {
        eventTarget.addEventListener(Events.ANNOTATION_CUT_MERGE_PROCESS_COMPLETED, this.annotationCutMergeCompletedBinded);
    }
    removeListeners() {
        eventTarget.removeEventListener(Events.ANNOTATION_CUT_MERGE_PROCESS_COMPLETED, this.annotationCutMergeCompletedBinded);
    }
    annotationCutMergeCompleted(evt) {
        const { sourceAnnotation: annotation } = evt.detail;
        if (!this.splineToolNames.includes(annotation?.metadata?.toolName) ||
            !this.configuration.simplifiedSpline) {
            return;
        }
        convertContourSegmentationAnnotation(annotation);
    }
}
export default SplineContourSegmentationTool;
